@@ -6,26 +6,15 @@ from rest_framework.views import APIView
 from rest_framework.response import Response
 from rest_framework.generics import GenericAPIView
 from rest_framework.permissions import IsAuthenticated, AllowAny
-from rest_framework.authentication import SessionAuthentication, \
-    TokenAuthentication
 from rest_framework.authtoken.models import Token
 from rest_framework.generics import RetrieveUpdateAPIView
 
-from app_settings import (TokenSerializer, UserDetailsSerializer,
+from .app_settings import (TokenSerializer, UserDetailsSerializer,
     LoginSerializer, PasswordResetSerializer, PasswordResetConfirmSerializer,
     PasswordChangeSerializer)
 
 
-class LoggedInRESTAPIView(APIView):
-    authentication_classes = ((SessionAuthentication, TokenAuthentication))
-    permission_classes = ((IsAuthenticated,))
-
-
-class LoggedOutRESTAPIView(APIView):
-    permission_classes = ((AllowAny,))
-
-
-class Login(LoggedOutRESTAPIView, GenericAPIView):
+class Login(GenericAPIView):
 
     """
     Check the credentials and return the REST Token
@@ -36,15 +25,11 @@ class Login(LoggedOutRESTAPIView, GenericAPIView):
     Accept the following POST parameters: username, password
     Return the REST Framework Token Object's key.
     """
-
+    permission_classes = (AllowAny,)
     serializer_class = LoginSerializer
     token_model = Token
     response_serializer = TokenSerializer
 
-    def get_serializer(self):
-        return self.serializer_class(data=self.request.DATA,
-            context={'request': self.request, 'view': self})
-
     def login(self):
         self.user = self.serializer.object['user']
         self.token, created = self.token_model.objects.get_or_create(
@@ -61,14 +46,14 @@ class Login(LoggedOutRESTAPIView, GenericAPIView):
             status=status.HTTP_400_BAD_REQUEST)
 
     def post(self, request, *args, **kwargs):
-        self.serializer = self.get_serializer()
+        self.serializer = self.get_serializer(data=self.request.DATA)
         if not self.serializer.is_valid():
             return self.get_error_response()
         self.login()
         return self.get_response()
 
 
-class Logout(LoggedInRESTAPIView):
+class Logout(APIView):
 
     """
     Calls Django logout method and delete the Token object
@@ -76,6 +61,7 @@ class Logout(LoggedInRESTAPIView):
 
     Accepts/Returns nothing.
     """
+    permission_classes = (AllowAny,)
 
     def post(self, request):
         try:
@@ -89,7 +75,7 @@ class Logout(LoggedInRESTAPIView):
                         status=status.HTTP_200_OK)
 
 
-class UserDetails(LoggedInRESTAPIView, RetrieveUpdateAPIView):
+class UserDetails(RetrieveUpdateAPIView):
 
     """
     Returns User's details in JSON format.
@@ -101,12 +87,13 @@ class UserDetails(LoggedInRESTAPIView, RetrieveUpdateAPIView):
     Returns the updated UserProfile and/or User object.
     """
     serializer_class = UserDetailsSerializer
+    permission_classes = (IsAuthenticated,)
 
     def get_object(self):
         return self.request.user
 
 
-class PasswordReset(LoggedOutRESTAPIView, GenericAPIView):
+class PasswordReset(GenericAPIView):
 
     """
     Calls Django Auth PasswordResetForm save method.
@@ -116,6 +103,7 @@ class PasswordReset(LoggedOutRESTAPIView, GenericAPIView):
     """
 
     serializer_class = PasswordResetSerializer
+    permission_classes = (AllowAny,)
 
     def post(self, request, *args, **kwargs):
         # Create a serializer with request.DATA
@@ -130,7 +118,7 @@ class PasswordReset(LoggedOutRESTAPIView, GenericAPIView):
                          status=status.HTTP_200_OK)
 
 
-class PasswordResetConfirm(LoggedOutRESTAPIView, GenericAPIView):
+class PasswordResetConfirm(GenericAPIView):
 
     """
     Password reset e-mail link is confirmed, therefore this resets the user's password.
@@ -141,6 +129,7 @@ class PasswordResetConfirm(LoggedOutRESTAPIView, GenericAPIView):
     """
 
     serializer_class = PasswordResetConfirmSerializer
+    permission_classes = (AllowAny,)
 
     def post(self, request):
         serializer = self.get_serializer(data=request.DATA)
@@ -151,7 +140,7 @@ class PasswordResetConfirm(LoggedOutRESTAPIView, GenericAPIView):
         return Response({"success": "Password has been reset with the new password."})
 
 
-class PasswordChange(LoggedInRESTAPIView, GenericAPIView):
+class PasswordChange(GenericAPIView):
 
     """
     Calls Django Auth SetPasswordForm save method.
@@ -161,6 +150,7 @@ class PasswordChange(LoggedInRESTAPIView, GenericAPIView):
     """
 
     serializer_class = PasswordChangeSerializer
+    permission_classes = (IsAuthenticated,)
 
     def post(self, request):
         serializer = self.get_serializer(data=request.DATA)
